searchData={"items":[{"type":"module","title":"InputEvent","doc":"Elixir interface to Linux input event devices","ref":"InputEvent.html"},{"type":"function","title":"InputEvent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"InputEvent.html#child_spec/1"},{"type":"function","title":"InputEvent.enumerate/0","doc":"Scan the system for input devices and return information on each one.","ref":"InputEvent.html#enumerate/0"},{"type":"function","title":"InputEvent.info/1","doc":"Return information about this input event device","ref":"InputEvent.html#info/1"},{"type":"function","title":"InputEvent.start_link/1","doc":"Start a GenServer that reports events from the specified input event device\n\nOptions:\n* `:path` - the path to the input event device (e.g., `\"/dev/input/event0\"`)\n* `:grab` - set to true to prevent events from being passed to other applications (defaults to `false`)\n* `:repeat_delay` - delay in milliseconds before a key press repeats\n* `:repeat_period` - period in milliseconds in which a key press will repeat\n* `:receiver` - the pid or name of the process that receives events (defaults to the process that calls `start_link/1`\n\nNote that passing the device path rather than a keyword list to\n`start_link/1` is deprecated.\n\nWhen adjusting the key repeat rate, you must set BOTH `:repeat_delay` and\n`:repeat_period` for `input_event` to make the change. Be careful setting\nrepeat timing in multiple places on the same device path! You might override\nyour own settings!","ref":"InputEvent.html#start_link/1"},{"type":"function","title":"InputEvent.stop/1","doc":"Stop the InputEvent GenServer.","ref":"InputEvent.html#stop/1"},{"type":"type","title":"InputEvent.code/0","doc":"Event code\n\nUsually these are translated to an atom that corresponds with the Linux event code.\nEvent codes depend on the event type.","ref":"InputEvent.html#t:code/0"},{"type":"type","title":"InputEvent.code_number/0","doc":"","ref":"InputEvent.html#t:code_number/0"},{"type":"type","title":"InputEvent.event/0","doc":"Event structure","ref":"InputEvent.html#t:event/0"},{"type":"type","title":"InputEvent.events_message/0","doc":"Message that is sent to the caller when input event received","ref":"InputEvent.html#t:events_message/0"},{"type":"type","title":"InputEvent.options/0","doc":"Options for the InputEvent Genserver","ref":"InputEvent.html#t:options/0"},{"type":"type","title":"InputEvent.type/0","doc":"Event type\n\nUsually these are translated to an atom that corresponds with the Linux event type.","ref":"InputEvent.html#t:type/0"},{"type":"type","title":"InputEvent.type_name/0","doc":"The type of event","ref":"InputEvent.html#t:type_name/0"},{"type":"type","title":"InputEvent.type_number/0","doc":"An unknown event type","ref":"InputEvent.html#t:type_number/0"},{"type":"type","title":"InputEvent.value/0","doc":"Event value\n\nSee the event type and code for how to interpret the value. For example, it could be a\n0 or 1 signifying a key press or release, or it could be an x or y coordinate or delta.","ref":"InputEvent.html#t:value/0"},{"type":"module","title":"InputEvent.Info","doc":"Information about a input event file","ref":"InputEvent.Info.html"},{"type":"function","title":"InputEvent.Info.decode_report_info/2","doc":"Helper function for decoding raw report information from the port driver.","ref":"InputEvent.Info.html#decode_report_info/2"},{"type":"type","title":"InputEvent.Info.report_info/0","doc":"","ref":"InputEvent.Info.html#t:report_info/0"},{"type":"type","title":"InputEvent.Info.t/0","doc":"","ref":"InputEvent.Info.html#t:t/0"},{"type":"extras","title":"InputEvent","doc":"# InputEvent\n\n[![Hex version](https://img.shields.io/hexpm/v/input_event.svg \"Hex version\")](https://hex.pm/packages/input_event)\n[![API docs](https://img.shields.io/hexpm/v/input_event.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/input_event)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/nerves-web-kiosk/input_event/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/nerves-web-kiosk/input_event/tree/main)\n\nElixir interface to Linux input event devices. Using `input_event`, you can\n\n* Find out what keyboards, joysticks, mice, touchscreens, etc. are connected\n* Get information on what kinds of events they can produce\n* Get decoded events sent to you\n\nThis library is intended for use with Nerves. If you're running a desktop Linux\ndistribution, this can still work, but you'll likely want to use a higher level\nAPI for receiving events.","ref":"readme.html"},{"type":"extras","title":"Usage - InputEvent","doc":"InputEvent can be used to monitor `/dev/input/event*` devices and report decoded\ndata to the parent process. The event reports follow the [Linux\ndocumentation](https://elixir.bootlin.com/linux/latest/source/Documentation/input/event-codes.rst)\nfairly closely, but it's easiest to understand by example.\n\nStart by looking for the device you want to monitor:\n\n```elixir\niex> InputEvent.enumerate\n[\n  {\"/dev/input/event0\",\n   %InputEvent.Info{\n     bus: 0,\n     input_event_version: \"1.0.1\",\n     name: \"FT5406 memory based driver\",\n     product: 0,\n     report_info: [\n       ev_abs: [\n         abs_x: %{flat: 0, fuzz: 0, max: 800, min: 0, resolution: 0, value: 0},\n         abs_y: %{flat: 0, fuzz: 0, max: 480, min: 0, resolution: 0, value: 0},\n         abs_mt_slot: %{\n           flat: 0,\n           fuzz: 0,\n           max: 9,\n           min: 0,\n           resolution: 0,\n           value: 0\n         },\n         abs_mt_position_x: %{\n           flat: 0,\n           fuzz: 0,\n           max: 800,\n           min: 0,\n           resolution: 0,\n           value: 0\n         },\n         abs_mt_position_y: %{\n           flat: 0,\n           fuzz: 0,\n           max: 480,\n           min: 0,\n           resolution: 0,\n           value: 0\n         },\n         abs_mt_tracking_id: %{\n           flat: 0,\n           fuzz: 0,\n           max: 65535,\n           min: 0,\n           resolution: 0,\n           value: 0\n         }\n       ],\n       ev_key: [:btn_touch]\n     ],\n     vendor: 0,\n     version: 0\n   }}\n]\n```\n\nThere's a touchscreen at `/dev/input/event0`, so let's open it:\n\n```elixir\niex> InputEvent.start_link(\"/dev/input/event0\")\n{:ok, #PID }\n```\n\nTouch the screen to test\n\n```elixir\niex> flush\n{:input_event, \"/dev/input/event0\",\n [\n   {:ev_abs, :abs_mt_tracking_id, 1},\n   {:ev_abs, :abs_mt_position_x, 350},\n   {:ev_abs, :abs_mt_position_y, 119},\n   {:ev_key, :btn_touch, 1},\n   {:ev_abs, :abs_x, 350},\n   {:ev_abs, :abs_y, 119}\n ]}\n{:input_event, \"/dev/input/event0\",\n [\n   {:ev_abs, :abs_mt_position_x, 352},\n   {:ev_abs, :abs_mt_position_y, 122},\n   {:ev_abs, :abs_x, 352},\n   {:ev_abs, :abs_y, 122}\n ]}\n{:input_event, \"/dev/input/event0\",\n [{:ev_abs, :abs_mt_tracking_id, -1}, {:ev_key, :btn_touch, 0}]}\n{:input_event, \"/dev/input/event0\",\n [\n   {:ev_abs, :abs_mt_tracking_id, 2},\n   {:ev_abs, :abs_mt_position_x, 361},\n   {:ev_abs, :abs_mt_position_y, 361},\n   {:ev_abs, :abs_mt_slot, 1},\n   {:ev_abs, :abs_mt_tracking_id, 3},\n   {:ev_abs, :abs_mt_position_x, 425},\n   {:ev_abs, :abs_mt_position_y, 139},\n   {:ev_key, :btn_touch, 1},\n   {:ev_abs, :abs_x, 361},\n   {:ev_abs, :abs_y, 361}\n ]}\n{:input_event, \"/dev/input/event0\", [{:ev_abs, :abs_mt_position_y, 142}]}\n{:input_event, \"/dev/input/event0\",\n [\n   {:ev_abs, :abs_mt_slot, 0},\n   {:ev_abs, :abs_mt_position_y, 363},\n   {:ev_abs, :abs_mt_slot, 1},\n   {:ev_abs, :abs_mt_position_x, 427},\n   {:ev_abs, :abs_mt_position_y, 147},\n   {:ev_abs, :abs_y, 363}\n ]}\n{:input_event, \"/dev/input/event0\",\n [{:ev_abs, :abs_mt_position_x, 428}, {:ev_abs, :abs_mt_position_y, 149}]}\n{:input_event, \"/dev/input/event0\",\n [\n   {:ev_abs, :abs_mt_slot, 0},\n   {:ev_abs, :abs_mt_tracking_id, -1},\n   {:ev_abs, :abs_mt_slot, 1},\n   {:ev_abs, :abs_mt_tracking_id, -1},\n   {:ev_key, :btn_touch, 0}\n ]}\n:ok\n```","ref":"readme.html#usage"},{"type":"extras","title":"Examples - InputEvent","doc":"Enumerating attached devices can be really helpful in figuring out what kind of\nmessages that you'll be sent. Here are other examples:\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Keyboard - InputEvent","doc":"```elixir\n  {\"/dev/input/event3\",\n   %InputEvent.Info{\n     bus: 3,\n     input_event_version: \"1.0.1\",\n     name: \"Logitech K520\",\n     product: 8209,\n     report_info: [\n       ev_rep: %{delay: 250, period: 33},\n       ev_led: [:led_numl, :led_capsl, :led_scrolll, :led_compose, :led_kana],\n       ev_msc: [:msc_scan],\n       ev_abs: [\n         abs_volume: %{\n           flat: 0,\n           fuzz: 0,\n           max: 652,\n           min: 1,\n           resolution: 0,\n           value: 0\n         }\n       ],\n       ev_rel: [:rel_hwheel],\n       ev_key: [:key_esc, :key_1, :key_2, :key_3, :key_4, :key_5, :key_6,\n        :key_7, :key_8, :key_9, :key_0, :key_minus, :key_equal, :key_backspace,\n        :key_tab, :key_q, :key_w, :key_e, :key_r, :key_t, :key_y, :key_u,\n        :key_i, :key_o, :key_p, :key_leftbrace, :key_rightbrace, ...]\n     ],\n     vendor: 1133,\n     version: 273\n   }}\n```\n\nEvents from a keyboard look like:\n\n```elixir\n{:input_event, \"/dev/input/event3\", [{:ev_key, :key_f, 1}]}\n{:input_event, \"/dev/input/event3\", [{:ev_key, :key_f, 0}]}\n```\n\nIn the tuple, `{:ev_key, :key_f, 1}`, the third element is `0` for key up, `1`\nfor key down, and `2` for key repeat.\n\n#","ref":"readme.html#keyboard"},{"type":"extras","title":"Mouse - InputEvent","doc":"```elixir\n  {\"/dev/input/event2\",\n   %InputEvent.Info{\n     bus: 3,\n     input_event_version: \"1.0.1\",\n     name: \"Logitech M310\",\n     product: 4132,\n     report_info: [\n       ev_msc: [:msc_scan],\n       ev_rel: [:rel_x, :rel_y, :rel_hwheel, :rel_wheel],\n       ev_key: [:btn_left, :btn_right, :btn_middle, :btn_side, :btn_extra,\n        :btn_forward, :btn_back, :btn_task, 280, 281, 282, 283, 284, 285, 286,\n        287]\n     ],\n     vendor: 1133,\n     version: 273\n   }}\n```\n\nEvents from a mouse look like:\n\n```elixir\n{:input_event, \"/dev/input/event2\", [{:ev_rel, :rel_x, 12}]}\n{:input_event, \"/dev/input/event2\",\n [{:ev_rel, :rel_x, 14}, {:ev_rel, :rel_y, -1}]}\n```\n\nNotice that if there's no movement in an axis that you won't get an update for that axis.\n\n#","ref":"readme.html#mouse"},{"type":"extras","title":"Joystick - InputEvent","doc":"```elixir\n  {\"/dev/input/event15\",\n   %InputEvent.Info{\n     bus: 3,\n     input_event_version: \"1.0.1\",\n     name: \"Microsoft X-Box 360 pad\",\n     product: 654,\n     report_info: [\n       ev_ff: 'PQXYZ`',\n       ev_abs: [\n         abs_x: %{\n           flat: 128,\n           fuzz: 16,\n           max: 32767,\n           min: -32768,\n           resolution: 0,\n           value: 0\n         },\n         abs_y: %{\n           flat: 128,\n           fuzz: 16,\n           max: 32767,\n           min: -32768,\n           resolution: 0,\n           value: 0\n         },\n         abs_z: %{flat: 0, fuzz: 0, max: 255, min: 0, resolution: 0, value: 0},\n         abs_rx: %{\n           flat: 128,\n           fuzz: 16,\n           max: 32767,\n           min: -32768,\n           resolution: 0,\n           value: 0\n         },\n         abs_ry: %{\n           flat: 128,\n           fuzz: 16,\n           max: 32767,\n           min: -32768,\n           resolution: 0,\n           value: 0\n         },\n         abs_rz: %{flat: 0, fuzz: 0, max: 255, min: 0, resolution: 0, value: 0},\n         abs_hat0x: %{\n           flat: 0,\n           fuzz: 0,\n           max: 1,\n           min: -1,\n           resolution: 0,\n           value: 0\n         },\n         abs_hat0y: %{\n           flat: 0,\n           fuzz: 0,\n           max: 1,\n           min: -1,\n           resolution: 0,\n           value: 0\n         }\n       ],\n       ev_key: [:btn_a, :btn_b, :btn_x, :btn_y, :btn_tl, :btn_tr, :btn_select,\n        :btn_start, :btn_mode, :btn_thumbl, :btn_thumbr]\n     ],\n     vendor: 1118,\n     version: 272\n   }}\n```\n\n#","ref":"readme.html#joystick"},{"type":"extras","title":"Power button - InputEvent","doc":"```elixir\n  {\"/dev/input/event0\",\n   %InputEvent.Info{\n     bus: 25,\n     input_event_version: \"1.0.1\",\n     name: \"Power Button\",\n     product: 1,\n     report_info: [ev_key: [:key_power]],\n     vendor: 0,\n     version: 0\n   }}\n```\n\nThe power button input device works just like a one-button keyboard.","ref":"readme.html#power-button"},{"type":"extras","title":"Grab device - InputEvent","doc":"Devices can be grabbed to prevent output into other applications.\n\n```elixir\niex> InputEvent.start_link(path: \"/dev/input/event0\", grab: true)\n{:ok, #PID }\n```\n\n#","ref":"readme.html#grab-device"},{"type":"extras","title":"Permissions - InputEvent","doc":"To be able to read from `/dev/input/event*` you need to add user to the `input`\ngroup:\n\n```sh\nsudo usermod -a -G input  \n```\n\nAnd restart user session.","ref":"readme.html#permissions"}],"content_type":"text/markdown"}